@@ -21,6 +21,12 @@ def action_caller(service):
 
 
 SERVICE_VERSIONS = {
+    "advisor": [
+        "2020-07-21"
+    ],
+    "aiart": [
+        "2022-12-29"
+    ],
     "ams": [
         "2020-12-29"
     ],
@@ -30,6 +36,12 @@ SERVICE_VERSIONS = {
     "apigateway": [
         "2018-08-08"
     ],
+    "apm": [
+        "2021-06-22"
+    ],
+    "asr": [
+        "2019-06-14"
+    ],
     "autoscaling": [
         "2018-04-19"
     ],
@@ -57,12 +69,21 @@ SERVICE_VERSIONS = {
     "cdb": [
         "2017-03-20"
     ],
+    "cdc": [
+        "2020-12-14"
+    ],
     "cdn": [
         "2018-06-06"
     ],
     "cdwdoris": [
         "2021-12-28"
     ],
+    "cdwpg": [
+        "2020-12-30"
+    ],
+    "cfg": [
+        "2021-08-20"
+    ],
     "cfs": [
         "2019-07-19"
     ],
@@ -91,12 +112,24 @@ SERVICE_VERSIONS = {
     "cmq": [
         "2019-03-04"
     ],
+    "config": [
+        "2022-08-02"
+    ],
+    "controlcenter": [
+        "2023-01-10"
+    ],
     "csip": [
         "2022-11-21"
     ],
+    "ctsdb": [
+        "2023-02-02"
+    ],
     "cvm": [
         "2017-03-12"
     ],
+    "cwp": [
+        "2018-02-28"
+    ],
     "cynosdb": [
         "2019-01-07"
     ],
@@ -150,6 +183,9 @@ SERVICE_VERSIONS = {
     "es": [
         "2018-04-16"
     ],
+    "facefusion": [
+        "2022-09-27"
+    ],
     "faceid": [
         "2018-03-01"
     ],
@@ -165,9 +201,15 @@ SERVICE_VERSIONS = {
     "gse": [
         "2019-11-12"
     ],
+    "gwlb": [
+        "2024-09-06"
+    ],
     "iai": [
         "2020-03-03"
     ],
+    "iap": [
+        "2024-07-13"
+    ],
     "ims": [
         "2020-12-29"
     ],
@@ -192,6 +234,9 @@ SERVICE_VERSIONS = {
     "live": [
         "2018-08-01"
     ],
+    "lke": [
+        "2023-11-30"
+    ],
     "mariadb": [
         "2017-03-12"
     ],
@@ -232,9 +277,18 @@ SERVICE_VERSIONS = {
     "privatedns": [
         "2020-10-28"
     ],
+    "pts": [
+        "2021-07-28"
+    ],
+    "rce": [
+        "2020-11-03"
+    ],
     "redis": [
         "2018-04-12"
     ],
+    "region": [
+        "2022-06-27"
+    ],
     "rum": [
         "2021-06-22"
     ],
@@ -266,15 +320,24 @@ SERVICE_VERSIONS = {
     "tat": [
         "2020-10-28"
     ],
+    "tbaas": [
+        "2018-04-16"
+    ],
     "tcaplusdb": [
         "2019-08-23"
     ],
     "tchd": [
         "2023-03-06"
     ],
+    "tcmpp": [
+        "2024-08-01"
+    ],
     "tcr": [
         "2019-09-24"
     ],
+    "tcsas": [
+        "2025-01-06"
+    ],
     "tcss": [
         "2020-11-01"
     ],
@@ -296,7 +359,8 @@ SERVICE_VERSIONS = {
         "2019-09-19"
     ],
     "tke": [
-        "2018-05-25"
+        "2018-05-25",
+        "2022-05-01"
     ],
     "tms": [
         "2020-12-29"
@@ -304,22 +368,35 @@ SERVICE_VERSIONS = {
     "tmt": [
         "2018-03-21"
     ],
+    "trabbit": [
+        "2023-04-18"
+    ],
+    "trro": [
+        "2022-03-25"
+    ],
     "trtc": [
         "2019-07-22"
     ],
     "tts": [
         "2019-08-23"
     ],
+    "vclm": [
+        "2024-05-23"
+    ],
     "vm": [
         "2021-09-22",
         "2020-12-29"
     ],
     "vod": [
-        "2018-07-17"
+        "2018-07-17",
+        "2024-07-18"
     ],
     "vpc": [
         "2017-03-12"
     ],
+    "waf": [
+        "2018-01-25"
+    ],
     "wedata": [
         "2021-08-20"
     ],
